/*
 * Created on 01-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.tab;

import org.eclipse.swt.graphics.GC;
import org.herac.tuxguitar.gui.tab.layout.ViewLayout;
import org.herac.tuxguitar.song.models.Component;
import org.herac.tuxguitar.song.models.Duration;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public interface MeasureComponent {    
	public Component getComponent();
	public void update(ViewLayout layout);
    public void paint(ViewLayout layout,GC gc, int fromX, int fromY);
    public void setDuration(Duration duration);
    public Duration getDuration();
    public void setStart(long start);
    public long getStart();
    public int getPosX();
    public int getPosY();        
    public int getSpan();    
    //public void setSpan(int span);
    public int getPointX();
    public int getPointY();    
}
